pub struct TimeWindow {
pub start: f64,
pub end: f64,
}Expand description
A [start, end] service window, in the same time unit as the matrix.
Not enforced yet by the construction heuristic — kept here so the model is stable for the upcoming time-window constraint.
Fields
start: f64end: f64Trait Implementations
Sourceimpl Clone for TimeWindow
impl Clone for TimeWindow
Sourcefn clone(&self) -> TimeWindow
fn clone(&self) -> TimeWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TimeWindow
Sourceimpl Debug for TimeWindow
impl Debug for TimeWindow
Sourceimpl PartialEq for TimeWindow
impl PartialEq for TimeWindow
Sourcefn eq(&self, other: &TimeWindow) -> bool
fn eq(&self, other: &TimeWindow) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TimeWindow